@@ -1,6 +1,8 @@
 from rest_framework import exceptions, permissions
 
 __all__ = [
+    "IsMe",
+    "IsMine",
     "IsSafeMethods",
     "IsAnonymous",
     "IsValidVersion",
@@ -10,6 +12,16 @@ __all__ = [
 ]
 
 
+class IsMe(permissions.BasePermission):
+    def has_object_permission(self, request, view, obj):
+        return request.user == obj
+
+
+class IsMine(permissions.BasePermission):
+    def has_object_permission(self, request, view, obj):
+        return request.user == obj.user
+
+
 class IsSafeMethods(permissions.BasePermission):
     """Allows access only if method is in permissions.SAFE_METHODS."""
 
